# Generated by Django 3.0.11 on 2021-06-30 15:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qrtoolkit_core', '0007_auto_20210630_1417'),
    ]

    operations = [
        migrations.AlterField(
            model_name='apihit',
            name='action',
            field=models.CharField(choices=[('basic_info', 'Basic Info'), ('kiosk', 'Kiosk'), ('json', 'Json Response'), ('redirect', 'Redirect'), ('api_call', 'Api Call'), ('error', 'Error')], default='basic_info', max_length=16),
        ),
    ]
